@@ -2,7 +2,7 @@
 
 /*
     UTStatsDB
-    Copyright (C) 2002-2007  Patrick Contreras / Paul Gallier
+    Copyright (C) 2002-2008  Patrick Contreras / Paul Gallier
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -26,7 +26,7 @@ $magic = get_magic_quotes_gpc();
 $magicrt = get_magic_quotes_runtime();
 $adminver = new AdminVer;
 $adminver->major = 3;
-$adminver->minor = 02;
+$adminver->minor = 03;
 $adminver->extra = "";
 $updatereq = 0;
 
@@ -102,18 +102,22 @@ if (!isset($dbtype) || $dbtype == "") {
   echo "<b>Error: You must set the &amp;dbtype variable in your statsdb.inc.php file to your SQL database type (MySQL/SQLite).</b><br />\n";
   $error++;
 }
-if (!isset($SQLhost) || $SQLhost == "") {
-  echo "<b>Error: You must set the &amp;SQLhost variable in statsdb.inc.php to your SQL database server, usually 'localhost'.</b><br />\n";
-  $error++;
-}
-if (!isset($SQLus) || $SQLus == "") {
-  echo "<b>Error: You must set the &amp;SQLus variable in statsdb.inc.php to your SQL database username.</b><br />\n";
-  $error++;
-}
-if (!isset($SQLpw) || $SQLpw == "") {
-  echo "<b>Error: You must set the &amp;SQLpw variable in statsdb.inc.php to your SQL database password.</b><br />\n";
-  $error++;
+
+if (strtolower($dbtype) != "sqlite") {
+  if (!isset($SQLhost) || $SQLhost == "") {
+    echo "<b>Error: You must set the &amp;SQLhost variable in statsdb.inc.php to your SQL database server, usually 'localhost'.</b><br />\n";
+    $error++;
+  }
+  if (!isset($SQLus) || $SQLus == "") {
+    echo "<b>Error: You must set the &amp;SQLus variable in statsdb.inc.php to your SQL database username.</b><br />\n";
+    $error++;
+  }
+  if (!isset($SQLpw) || $SQLpw == "") {
+    echo "<b>Error: You must set the &amp;SQLpw variable in statsdb.inc.php to your SQL database password.</b><br />\n";
+    $error++;
+  }
 }
+
 if (!isset($SQLdb) || $SQLdb == "") {
   echo "<b>Error: You must set the &amp;SQLdb variable in statsdb.inc.php to your SQL database name.</b><br />\n";
   $error++;
@@ -301,6 +305,7 @@ switch($Mode) {
     break;
   case "Add": // Add Configuration
     require_once("includes/adminconfig.php");
+    saveconfig();
     addconfig();
     break;
   case "Merge": // Verify Merge
@@ -313,6 +318,7 @@ switch($Mode) {
     break;
   case "MoveQuery": // Modify Query order
     require_once("includes/adminconfig.php");
+    saveconfig();
     movequery();
     break;
   case "Track": // Track Player Display
@@ -385,21 +391,22 @@ function menu_top() {
     $versioncheck = "";
 
   echo <<<EOF
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-<html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
   <title>UTStatsDB Admin</title>
-  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-  <link rel="stylesheet" type="text/css" media="screen" href="resource/admin.css">
-  <meta name="MSSmartTagsPreventParsing" content="TRUE">
-  <link rel="shortcut icon" href="resource/favicon.ico">
-  <link rel="icon" href="resource/favicon.ico">
+  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
+  <link rel="stylesheet" type="text/css" media="screen" href="resource/admin.css" />
+  <meta name="MSSmartTagsPreventParsing" content="TRUE" />
+  <link rel="shortcut icon" href="resource/favicon.ico" />
+  <link rel="icon" href="resource/favicon.ico" />
 </head>
 <body>
 
 <div id="header">
   <div id="header-logo">
-    <a href="index.php"><img src="resource/adminlogo.gif" alt="UTStatsDB Logo"></a>
+    <a href="index.php"><img src="resource/adminlogo.gif" alt="UTStatsDB Logo" /></a>
   </div>
 </div>
 
@@ -448,7 +455,7 @@ function menu_bottom() {
   </div>
 
   <div id="footer">
-    Visit the <a href="http://ut2003stats.sourceforge.net">UTStatsDB</a> SourceForge Project
+    Visit the <a href="http://www.utstatsdb.com">UTStatsDB</a> website.
   </div>
 </body>
 </html>
@@ -488,6 +495,19 @@ function updatedb() {
     update302();
   }
 
+  $ver = currentver();
+  if ($ver == -1) {
+    $versioncheck = "Version check error!<br />\n";
+    menu_bottom();
+    exit;
+  }
+  list($vermajor, $verminor, $verextra) = $ver;
+  if ($vermajor == 3 && $verminor == 2) {
+    echo "Updating database to version 3.03....<br /><br />\n";
+    include_once("includes/adminupdate.php");
+    update303();
+  }
+
   menu_bottom();
   exit;
 }
@@ -564,12 +584,13 @@ function logparse() {
 //=============================================================================
 function login() {
   echo <<<EOF
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-<html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
   <title>UTStatsDB Admin Login</title>
-  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-  <link rel="icon" href="resource/uicon.png" type="image/png">
+  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
+  <link rel="icon" href="resource/uicon.png" type="image/png" />
   <style type="text/css">
     .sidebox {border: 1px #000000 solid}
   </style>
@@ -580,10 +601,10 @@ function login() {
   </script>
 </head>
 
-<body text="#101031" onLoad="setFocus()">
+<body text="#101031" onload="setFocus()">
 
 <form name="login_form" method="post" action="admin.php">
-  <input type="hidden" name="Mode" value="Login">
+  <input type="hidden" name="Mode" value="Login" />
   <table bgcolor="#cccccc" cellspacing="0" cellpadding="5" class="sidebox" width="250">
     <tr>
       <td bgcolor="#000066" align="center" colspan="2">
@@ -595,12 +616,12 @@ function login() {
         <b>Password:</b>
       </td>
       <td align="left">
-        <input type="password" name="Pass" maxlength="25">
+        <input type="password" name="Pass" maxlength="25" />
       </td>
     </tr>
     <tr>
       <td align="center" colspan="2">
-        <input type="submit" name="ModeS" value="Login">
+        <input type="submit" name="ModeS" value="Login" />
       </td>
     </tr>
   </table>
@@ -615,12 +636,13 @@ EOF;
 
 function invalid_login() {
   echo <<<EOF
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-<html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
   <title>Invalid Login</title>
-  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-  <link rel="icon" href="resource/uicon.png" type="image/png">
+  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
+  <link rel="icon" href="resource/uicon.png" type="image/png" />
 </head>
 <body text="#ff0000">
 
@@ -636,12 +658,13 @@ EOF;
 
 function auth_required() {
   echo <<<EOF
-<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" "http://www.w3.org/TR/html4/loose.dtd">
-<html>
+<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN" "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
+
+<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="en" lang="en">
 <head>
   <title>Authorization Required</title>
-  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
-  <link rel="icon" href="resource/uicon.png" type="image/png">
+  <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1" />
+  <link rel="icon" href="resource/uicon.png" type="image/png" />
 </head>
 <body text="#ff0000">
 
