@@ -2,7 +2,7 @@
 
 /*
     UTStatsDB
-    Copyright (C) 2002-2007  Patrick Contreras / Paul Gallier
+    Copyright (C) 2002-2008  Patrick Contreras / Paul Gallier
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -33,7 +33,7 @@ function findpwk($player, $weapon) // Player, Weapon
   if ($nohtml)
     $break = "";
   else
-    $break = "<br>";
+    $break = "<br />";
 
   $result = sql_queryn($link, "SELECT pwk_num FROM {$dbpre}pwkills WHERE pwk_player=$player AND pwk_weapon=$weapon LIMIT 1");
   if (!$result) {
@@ -62,7 +62,7 @@ function findmwk($map, $weapon) // Map, Weapon
   if ($nohtml)
     $break = "";
   else
-    $break = "<br>";
+    $break = "<br />";
 
   $result = sql_queryn($link, "SELECT mwk_num FROM {$dbpre}mwkills WHERE mwk_map=$map AND mwk_weapon=$weapon LIMIT 1");
   if (!$result) {
@@ -91,7 +91,7 @@ function findgwa($match, $player, $weapon) // Match, Player, Weapon
   if ($nohtml)
     $break = "";
   else
-    $break = "<br>";
+    $break = "<br />";
 
   $result = sql_queryn($link, "SELECT gwa_num FROM {$dbpre}gwaccuracy WHERE gwa_match=$match AND gwa_player=$player AND gwa_weapon=$weapon LIMIT 1");
   if (!$result) {
@@ -123,7 +123,7 @@ function storedata()
   if ($nohtml)
     $break = "";
   else
-    $break = "<br>";
+    $break = "<br />";
 
   if ($match->length <= 0)
     return 0;
@@ -158,7 +158,9 @@ function storedata()
   }
 
   // Save Match Data
-  $result = sql_queryn($link, "INSERT INTO {$dbpre}matches VALUES (NULL,{$match->servernum},'{$match->serverversion}',{$match->mapnum},{$match->gametnum},{$match->uttype},'$md','$sd',{$match->logger},'$logname',{$match->rpg},{$match->maxwave},{$match->difficulty},'{$match->mutators}',{$match->mapvoting},{$match->kickvoting},{$match->fraglimit},{$match->timelimit},{$match->overtime},{$match->minplayers},{$match->translocator},{$match->endtimedelay},{$match->balanceteams},{$match->playersbalanceteams},'{$match->friendlyfirescale}','{$match->linksetup}',{$match->gamespeed},{$match->healthforkills},{$match->allowsuperweapons},{$match->camperalarm},{$match->allowpickups},{$match->allowadrenaline},{$match->fullammo},{$match->starttime},{$match->length},{$match->numplayers},{$match->tot_kills},{$match->tot_deaths},{$match->tot_suicides},{$match->numteams},{$match->team[0]},{$match->team[1]},{$match->team[2]},{$match->team[3]},{$match->firstblood},{$match->headshots},0)");
+  if (strlen($match->mutators) > 255)
+    $match->mutators = substr($match->mutators, 0, 255);
+  $result = sql_queryn($link, "INSERT INTO {$dbpre}matches VALUES (NULL,{$match->servernum},'{$match->serverversion}',{$match->mapnum},{$match->gametnum},{$match->uttype},'$md','$sd',{$match->logger},'$logname',{$match->timeoffset},{$match->rpg},{$match->maxwave},{$match->difficulty},'{$match->mutators}',{$match->mapvoting},{$match->kickvoting},{$match->fraglimit},{$match->timelimit},{$match->overtime},{$match->minplayers},{$match->translocator},{$match->endtimedelay},{$match->balanceteams},{$match->playersbalanceteams},'{$match->friendlyfirescale}','{$match->linksetup}',{$match->gamespeed},{$match->healthforkills},{$match->allowsuperweapons},{$match->camperalarm},{$match->allowpickups},{$match->allowadrenaline},{$match->fullammo},{$match->starttime},{$match->length},{$match->numplayers},{$match->tot_kills},{$match->tot_deaths},{$match->tot_suicides},{$match->numteams},{$match->team[0]},{$match->team[1]},{$match->team[2]},{$match->team[3]},{$match->firstblood},{$match->headshots},0)");
   if (!$result) {
     echo "Error saving match data in database.{$break}\n";
     exit;
@@ -1497,7 +1499,7 @@ function storedata()
                 $weapsg[$wpn]["wp_chkills"] = $pwkkills;
                 $pwkresult = sql_queryn($link, "UPDATE {$dbpre}weapons SET wp_chkills=$pwkkills, wp_chkills_plr=$pnum, wp_chkills_gms=$plr_matches, wp_chkills_tm=$plr_time WHERE wp_num=$wpn LIMIT 1");
                 if (!$pwkresult) {
-                  echo "Error updating weapon entry [1].<br>\n";
+                  echo "Error updating weapon entry [1].<br />\n";
                   exit;
                 }
               }
@@ -1505,7 +1507,7 @@ function storedata()
                 $weapsg[$wpn]["wp_chdeaths"] = $pwkdeaths;
                 $pwkresult = sql_queryn($link, "UPDATE {$dbpre}weapons SET wp_chdeaths=$pwkdeaths, wp_chdeaths_plr=$pnum, wp_chdeaths_gms=$plr_matches, wp_chdeaths_tm=$plr_time WHERE wp_num=$wpn LIMIT 1");
                 if (!$pwkresult) {
-                  echo "Error updating weapon entry [2].<br>\n";
+                  echo "Error updating weapon entry [2].<br />\n";
                   exit;
                 }
               }
@@ -1513,7 +1515,7 @@ function storedata()
                 $weapsg[$wpn]["wp_chdeathshld"] = $pwkheld;
                 $pwkresult = sql_queryn($link, "UPDATE {$dbpre}weapons SET wp_chdeathshld=$pwkheld, wp_chdeathshld_plr=$pnum, wp_chdeathshld_gms=$plr_matches, wp_chdeathshld_tm=$plr_time WHERE wp_num=$wpn LIMIT 1");
                 if (!$pwkresult) {
-                  echo "Error updating weapon entry [3].<br>\n";
+                  echo "Error updating weapon entry [3].<br />\n";
                   exit;
                 }
               }
@@ -1521,7 +1523,7 @@ function storedata()
                 $weapsg[$wpn]["wp_chsuicides"] = $pwksuicides;
                 $pwkresult = sql_queryn($link, "UPDATE {$dbpre}weapons SET wp_chsuicides=$pwksuicides, wp_chsuicides_plr=$pnum, wp_chsuicides_gms=$plr_matches, wp_chsuicides_tm=$plr_time WHERE wp_num=$wpn LIMIT 1");
                 if (!$pwkresult) {
-                  echo "Error updating weapon entry [4].<br>\n";
+                  echo "Error updating weapon entry [4].<br />\n";
                   exit;
                 }
               }
