@@ -2,7 +2,7 @@
 
 /*
     UTStatsDB
-    Copyright (C) 2002-2007  Patrick Contreras / Paul Gallier
+    Copyright (C) 2002-2008  Patrick Contreras / Paul Gallier
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -24,6 +24,9 @@ if (preg_match("/logutevents.php/i", $_SERVER["PHP_SELF"])) {
   die();
 }
 
+define("TIME_OFFSET", 118.25); // This seems to be fairly accurate for UT '99
+
+// Server Info
 function tagut_info($i, $data)
 {
   global $match;
@@ -56,7 +59,7 @@ function tagut_info($i, $data)
 
       $match->timezone = substr($mdt, $p);
       $match->matchdate = strtotime(substr($mdt, 0, $r));
-
+      $match->timeoffset = TIME_OFFSET;
   	  break;
   	case "Server_ServerName":
       $match->servername = substr($data[3], 0, 45);
@@ -75,6 +78,7 @@ function tagut_info($i, $data)
   }
 }
 
+// Map Info
 function tagut_map($i, $data)
 {
   global $match;
@@ -99,6 +103,7 @@ function tagut_map($i, $data)
   }
 }
 
+// Match Info (New Game)
 function tagut_game($i, $data)
 {
   global $link, $dbpre, $config, $match, $break;
@@ -313,6 +318,7 @@ function tagut_game($i, $data)
   return 0;
 }
 
+// Player Event
 function tagut_player($i, $data)
 {
   global $match, $player, $relog;
@@ -490,6 +496,7 @@ function tagut_player($i, $data)
   }
 }
 
+// Start Game
 function tagut_game_start($i, $data)
 {
   global $match, $player;
@@ -499,7 +506,7 @@ function tagut_game_start($i, $data)
 
   $match->starttime = ctime($data[0]);
   $match->started = 1;
-  $match->startdate = $match->matchdate + intval($match->starttime / 110);
+  $match->startdate = $match->matchdate + intval($match->starttime / TIME_OFFSET);
 
   for ($n = 0; $n <= $match->maxplayer; $n++)
     if (isset($player[$n]))
@@ -509,6 +516,7 @@ function tagut_game_start($i, $data)
   gameevent($match->starttime, 0);
 }
 
+// Item Pickup
 function tagut_item_get($i, $data)
 {
   global $link, $dbpre, $match, $pickups, $break;
@@ -568,6 +576,7 @@ function tagut_item_get($i, $data)
     $match->maxpickups = $num;
 }
 
+// Kill Event
 function tagut_kill($killtype, $i, $data)
 {
   global $match, $player, $gkills, $gscores, $spree, $multi, $killmatch;
@@ -799,6 +808,7 @@ function tagut_kill($killtype, $i, $data)
   }
 }
 
+// Suicide Event
 function tagut_suicide($i, $data)
 {
   global $match, $player, $gkills, $gscores;
@@ -865,12 +875,14 @@ function tagut_suicide($i, $data)
   }
 }
 
+// Headshot
 function tagut_headshot($i, $data)
 {
   if ($i < 4)
     return;
 }
 
+// Flag Taken
 function tagut_flag_taken($i, $data)
 {
   global $match, $player;
@@ -891,6 +903,7 @@ function tagut_flag_taken($i, $data)
   flag_check($plr, $time, 1);
 }
 
+// Flag Dropped
 function tagut_flag_dropped($i, $data)
 {
   global $match, $player;
@@ -913,6 +926,7 @@ function tagut_flag_dropped($i, $data)
   $match->flagdropplr = $plr;
 }
 
+// Flag Pickup
 function tagut_flag_pickedup($i, $data)
 {
   global $match, $player;
@@ -934,6 +948,7 @@ function tagut_flag_pickedup($i, $data)
   }
 }
 
+// Flag Returned
 function tagut_flag_returned($i, $data)
 {
   global $match, $player;
@@ -954,6 +969,7 @@ function tagut_flag_returned($i, $data)
   flag_check($plr, $time, 0);
 }
 
+// Flag Timeout
 function tagut_flag_returned_timeout($i, $data)
 {
   global $match;
@@ -965,6 +981,7 @@ function tagut_flag_returned_timeout($i, $data)
   $tm = intval($data[2]);
 }
 
+// Flag Captured
 function tagut_flag_captured($i, $data)
 {
   global $match, $player, $gscores, $assist;
@@ -1010,6 +1027,7 @@ function tagut_flag_captured($i, $data)
   flag_check($plr, $time, 0);
 }
 
+// Translocator Throw
 function tagut_throw_translocator($i, $data)
 {
   if ($i < 3)
@@ -1019,6 +1037,7 @@ function tagut_throw_translocator($i, $data)
   $plr = check_player($data[2]);
 }
 
+// Translocate
 function tagut_translocate($i, $data)
 {
   if ($i < 3)
@@ -1028,6 +1047,7 @@ function tagut_translocate($i, $data)
   $plr = check_player($data[2]);
 }
 
+// Failed Translocate
 function tagut_translocate_fail($i, $data)
 {
   if ($i < 3)
@@ -1039,6 +1059,7 @@ function tagut_translocate_fail($i, $data)
 
 // Add TransGib
 
+// Powerup Activate
 function tagut_item_activate($i, $data)
 {
   if ($i < 4)
@@ -1051,6 +1072,7 @@ function tagut_item_activate($i, $data)
   $plr = check_player($data[3]);
 }
 
+// Powerup Deactivate
 function tagut_item_deactivate($i, $data)
 {
   if ($i < 4)
@@ -1323,4 +1345,44 @@ function tagut_weapdamage($i, $data) // 921.55	weap_damagegiven	Minigun	0	921
   pwa_add($plr, $weaponnum, -1, -1, $damage);
 }
 
+function tagut_say ($i, $data)
+{
+  global $player, $match, $chatlog;
+
+  if ($i < 4)
+    return;
+
+  $time = ctime($data[0]);
+  if (substr($data[2], 0, 5) == "spec_")
+    $plr = -1;
+  else {
+    $plr = check_player($data[2]);
+    if (!isset($player[$plr]) || $player[$plr]->name == "")
+      $plr = -1;
+  }
+
+  $chatlog[$match->numchat][0] = $plr;
+  $chatlog[$match->numchat][1] = 0;
+  $chatlog[$match->numchat][2] = $time;
+  $chatlog[$match->numchat++][3] = $data[3];
+}
+
+function tagut_teamsay ($i, $data)
+{
+  global $player, $match, $chatlog;
+
+  if ($i < 4)
+    return;
+
+  $time = ctime($data[0]);
+  $plr = check_player($data[2]);
+  if (!isset($player[$plr]) || $player[$plr]->name == "")
+    $plr = -1;
+
+  $chatlog[$match->numchat][0] = $plr;
+  $chatlog[$match->numchat][1] = $player[$plr]->team + 1;
+  $chatlog[$match->numchat][2] = $time;
+  $chatlog[$match->numchat++][3] = $data[3];
+}
+
 ?>
\ No newline at end of file
