@@ -2,7 +2,7 @@
 
 /*
     UTStatsDB
-    Copyright (C) 2002-2006  Patrick Contreras / Paul Gallier
+    Copyright (C) 2002-2008  Patrick Contreras / Paul Gallier
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ function loadconfig()
   }
 
   $conflogs = array(array());
-  $result = sql_querynb($link, "SELECT logpath,backuppath,prefix,noport,ftpserver,ftppath,passive,alllogs,ftpuser,ftppass,deftype,defteam,demoftppath,multicheck FROM {$dbpre}configlogs ORDER BY num");
+  $result = sql_querynb($link, "SELECT logpath,backuppath,prefix,chatprefix,chatrequire,noport,ftpserver,ftppath,passive,alllogs,ftpuser,ftppass,deftype,defteam,demoftppath,multicheck FROM {$dbpre}configlogs ORDER BY num");
   if ($result && sql_num_rows($result)) {
     $num = 0;
     while ($row = sql_fetch_row($result)) {
@@ -78,17 +78,19 @@ function loadconfig()
       $conflogs["logpath"][$num] = $magicrt ? stripslashes($row[0]) : $row[0];
       $conflogs["backuppath"][$num] = $magicrt ? stripslashes($row[1]) : $row[1];
       $conflogs["logprefix"][$num] = $magicrt ? stripslashes($row[2]) : $row[2];
-      $conflogs["noport"][$num] = intval($row[3]);
-      $conflogs["ftpserver"][$num] = $magicrt ? stripslashes($row[4]) : $row[4];
-      $conflogs["ftppath"][$num] = $magicrt ? stripslashes($row[5]) : $row[5];
-      $conflogs["ftppassive"][$num] = intval($row[6]);
-      $conflogs["alllogs"][$num] = intval($row[7]);
-      $conflogs["ftpuser"][$num] = $magicrt ? stripslashes($row[8]) : $row[8];
-      $conflogs["ftppass"][$num] = $magicrt ? stripslashes($row[9]) : $row[9];
-      $conflogs["deftype"][$num] = intval($row[10]);
-      $conflogs["defteam"][$num] = intval($row[11]);
-      $conflogs["demoftppath"][$num] = $magicrt ? stripslashes($row[12]) : $row[12];
-      $conflogs["multicheck"][$num] = intval($row[13]);
+      $conflogs["chatprefix"][$num] = $magicrt ? stripslashes($row[3]) : $row[3];
+      $conflogs["chatreq"][$num] = intval($row[4]);
+      $conflogs["noport"][$num] = intval($row[5]);
+      $conflogs["ftpserver"][$num] = $magicrt ? stripslashes($row[6]) : $row[6];
+      $conflogs["ftppath"][$num] = $magicrt ? stripslashes($row[7]) : $row[7];
+      $conflogs["ftppassive"][$num] = intval($row[8]);
+      $conflogs["alllogs"][$num] = intval($row[9]);
+      $conflogs["ftpuser"][$num] = $magicrt ? stripslashes($row[10]) : $row[10];
+      $conflogs["ftppass"][$num] = $magicrt ? stripslashes($row[11]) : $row[11];
+      $conflogs["deftype"][$num] = intval($row[12]);
+      $conflogs["defteam"][$num] = intval($row[13]);
+      $conflogs["demoftppath"][$num] = $magicrt ? stripslashes($row[14]) : $row[14];
+      $conflogs["multicheck"][$num] = intval($row[15]);
     }
     sql_free_result($result);
   }
@@ -105,10 +107,23 @@ function checkfile($pre, $noport, $file, &$fdate)
   global $files;
 
   $stattype = 0;
+  $prelen = strlen($pre);
   if (strstr($file, $pre) && (substr($file, -4) == ".log" || substr($file, -4) == ".txt")) {
     $i = strpos($file, $pre);
     $file = substr($file, $i + strlen($pre));
-    if (strstr($pre, "ngLog.")) { // UT '99 Log
+
+	if (strlen($file) == 19 && is_numeric(substr($file, 0, 8)) && substr($file, 8, 1) == "." && is_numeric(substr($file, 9, 6))) // UT3 Log
+	{
+		$fd_year = (int) substr($file, 0, 4);
+		$fd_month = (int) substr($file, 4, 2);
+		$fd_day = (int) substr($file, 6, 2);
+		$fd_hour = (int) substr($file, 9, 2);
+		$fd_min = (int) substr($file, 11, 2);
+		$fd_sec = (int) substr($file, 13, 2);
+        $fdate = sprintf("%04u-%02u-%02u %02u:%02u:%02u", $fd_year, $fd_month, $fd_day, $fd_hour, $fd_min, $fd_sec);
+        $stattype = 3;
+	}
+    else if (strstr($pre, "ngLog.") || (substr($file, 4, 1) == "." && substr($file, 7, 1) == "." && substr($file, 10, 1) == "." && substr($file, 13, 1) == "." && substr($file, 16, 1) == "." && substr($file, 19, 1) == ".")) { // UT '99 Log
       $tok = strtok($file, "."); // <year>
       $fd_year = (int) $tok;
       if ($tok != "") {
@@ -193,12 +208,17 @@ function release_lock()
     sql_queryn($link, "DO RELEASE_LOCK('$lockname')");
 }
 
-function dellog($file)
+function dellog($file,$chatfile)
 {
   global $config, $matchdate, $mapfile;
 
   unlink($file);
-  // Remove associated demo logs
+
+  // Remove chat log file
+  if ($chatfile != "" && file_exists($chatfile))
+    unlink($chatfile);
+
+  // Remove associated demo log file
   $demodir = $config["demodir"];
   $demoext = $config["demoext"];
   if (isset($matchdate) && isset($mapfile) && $demodir != "" && $demoext != "" && $matchdate && $mapfile) {
@@ -274,7 +294,7 @@ if ($nohtml) {
   $ebold = "";
 }
 else {
-  $break = "<br>";
+  $break = "<br />";
   $bold = "<b>";
   $ebold = "</b>";
 }
@@ -295,13 +315,13 @@ if (strtolower($dbtype) == "mysql") {
   $mysqlver = mysql_get_server_info();
   $dot = strpos($mysqlver, ".");
   if ($dot === FALSE) {
-    echo "Unable to determine MySQL version.<br>\n";
+    echo "Unable to determine MySQL version.<br />\n";
     exit;
   }
   $mysqlverh = (int) substr($mysqlver, 0, $dot);
   $dot2 = strpos($mysqlver, ".", $dot + 1);
   if ($dot2 === FALSE) {
-    echo "Unable to determine MySQL version.<br>\n";
+    echo "Unable to determine MySQL version.<br />\n";
     exit;
   }
   $mysqlverl = (int) substr($mysqlver, $dot + 1, $dot2 - $dot - 1);
@@ -344,6 +364,8 @@ while (isset($conflogs["ftpserver"][$ftpnum])) {
     $ftppassive = $conflogs["ftppassive"][$ftpnum];
     $logpath = $conflogs["logpath"][$ftpnum];
     $logprefix = $conflogs["logprefix"][$ftpnum];
+    $chatprefix = $conflogs["chatprefix"][$ftpnum];
+    $chatreq = $conflogs["chatreq"][$ftpnum];
     $noport = $conflogs["noport"][$ftpnum];
     $alllogs = $conflogs["alllogs"][$ftpnum];
     $demoftppath = $conflogs["demoftppath"][$ftpnum];
@@ -416,6 +438,8 @@ while (isset($conflogs["ftpserver"][$ftpnum])) {
 
           if (!$safemode)
             set_time_limit($config["php_timelimit"]); // Reset script timeout counter
+
+          // Retrieve log files
           $loglist = array();
           $listerr = 0;
           if (!($loglist = ftp_nlist($conn_id, "{$logprefix}*"))) {
@@ -477,6 +501,63 @@ while (isset($conflogs["ftpserver"][$ftpnum])) {
               echo "failed!{$break}\n";
           }
 
+          // Retrieve chat logs
+          if ($chatprefix != "") {
+            ftp_set_option($conn_id, FTP_TIMEOUT_SEC, 30);
+
+            if (!$safemode)
+              set_time_limit($config["php_timelimit"]); // Reset script timeout counter
+
+            $chatlist = array();
+            $chatlisterr = 0;
+            if (!($chatlist = ftp_nlist($conn_id, "{$chatprefix}*"))) {
+              if (!($chatlist = ftp_nlist($conn_id, ""))) {
+                echo "Error listing ftp directory '{$ftppath}{$chatprefix}*'.{$break}\n";
+                $chatlisterr = 1;
+              }
+            }
+            if ($test)
+              echo "[debug] listing '{$chatprefix}*' - records: ".count($chatlist)."{$break}\n";
+
+            $i = $chatfiles = 0;
+            $chatlogs = array();
+            $chatlogdate = array();
+            while(isset($chatlist[$i])) {
+              if ($test)
+                echo "[debug] Chatlist[$i] = '{$chatlist[$i]}'{$break}\n";
+              $file = $chatlist[$i++];
+              if (strstr($file, $chatprefix) && (substr($file, -4) == ".log" || substr($file, -4) == ".txt")) {
+                $fdate = "";
+                $stattype = checkfile($chatprefix, $noport, $file, $fdate);
+                if ($stattype) {
+                  $chatlogs[$chatfiles] = $file;
+                  $chatlogdate[$chatfiles++] = $fdate;
+                }
+              }
+            }
+            if (!$chatlisterr && !$chatfiles)
+              echo "No new chat logs to download.{$break}\n";
+
+            for ($i = 0; $i < $chatfiles - $ftplimit; $i++) {
+              if (!$safemode)
+                set_time_limit($config["php_timelimit"]); // Reset script timeout counter
+              $file = $chatlogs[$i];
+              echo "Downloading chat log '$file'....";
+              if (ftp_get($conn_id, "{$logpath}$file", "$file", FTP_BINARY)) {
+                echo "successful";
+                if (!$save) {
+                  if (ftp_delete($conn_id, $file))
+                    echo " - deleted.{$break}\n";
+                  else
+                    echo " - deletion failed!{$break}\n";
+                } else
+                  echo ".{$break}\n";
+              }
+              else
+                echo "failed!{$break}\n";
+            }
+          }
+
           // Retrieve demorecs
           if ($demoftppath != "") {
             if ((@ftp_chdir($conn_id, $demoftppath)) == TRUE)
@@ -534,6 +615,7 @@ while (isset($conflogs["ftpserver"][$ftpnum])) {
             }
           }
 
+          // Close connection
           ftp_close($conn_id);
           echo "{$break}\n";
         }
@@ -552,6 +634,7 @@ $lognum = 1;
 while (isset($conflogs["logpath"][$lognum])) {
   $files = $logs_saved = 0;
   $logs = array();
+  $chatlogs = array();
   $logtype = array();
   $logdate = array();
   $logpath = $conflogs["logpath"][$lognum];
@@ -568,6 +651,8 @@ while (isset($conflogs["logpath"][$lognum])) {
   }
 
   $logprefix = $conflogs["logprefix"][$lognum];
+  $chatprefix = $conflogs["chatprefix"][$lognum];
+  $chatreq = $conflogs["chatreq"][$lognum];
 
   if (isset($conflogs["noport"][$lognum]))
     $noport = $conflogs["noport"][$lognum];
@@ -588,6 +673,13 @@ while (isset($conflogs["logpath"][$lognum])) {
       if ($stattype = checkfile($logprefix, $noport, $file, $fdate)) {
         $logs[$files] = $file;
         $logtype[$files] = $stattype;
+        $chatlogs[$files] = "";
+        if ($chatprefix != "")
+        {
+          $chatfile = $chatprefix.substr($file, strlen($logprefix));
+          if (file_exists($logpath.$chatfile))
+            $chatlogs[$files] = $chatfile;
+        }
         $logdate[$files++] = $fdate;
       }
       if ($test)
@@ -596,7 +688,7 @@ while (isset($conflogs["logpath"][$lognum])) {
   }
   closedir($handle); 
   if ($files > 1)
-    array_multisort($logdate, $logs, $logtype, SORT_NUMERIC, SORT_ASC);
+    array_multisort($logdate, $logs, $chatlogs, $logtype, SORT_NUMERIC, SORT_ASC);
 
   $numinc = 0;
   $incomplete = array();
@@ -605,22 +697,31 @@ while (isset($conflogs["logpath"][$lognum])) {
       set_time_limit($config["php_timelimit"]); // Reset script timeout counter
     echo "Processing log '$logs[$i]'...";
     $file = $logpath.$logs[$i];
+    if ($chatlogs[$i] != "")
+      $chatfile = $logpath.$chatlogs[$i];
+    else
+      $chatfile = "";
     $logname = $logs[$i];
     $stattype = $logtype[$i];
-    $match->ended = parselog($file);
 
-    // Check for ended on map switch or server quit - set new ended type
-    if ($config["allowincomplete"] && $match->ended == 6) // Map Change
-      $match->ended = 16;
-    else if  ($config["allowincomplete"] >= 2 && $match->ended == 2) // Other Endgame
-      $match->ended = 12;
-    else if  ($config["allowincomplete"] >= 3 && $match->ended == 7) // Server Quit
-      $match->ended = 17;
+    if ($chatfile == "" && $chatreq)
+      $match->ended = 18;
+    else {
+      $match->ended = parselog($file,$chatfile);
 
-    if ($match->numhumans < 2 && !$config["savesingle"] && ($match->ended == 1 || $match->ended == 12 || $match->ended == 16 || $match->ended == 17))
-      $match->ended = 8;
-    else if ($match->numplayers < 2 && $config["savesingle"] == 1 && ($match->ended == 1 || $match->ended == 12 || $match->ended == 16 || $match->ended == 17))
-      $match->ended = 5;
+      // Check for ended on map switch or server quit - set new ended type
+      if ($config["allowincomplete"] && $match->ended == 6) // Map Change
+        $match->ended = 16;
+      else if  ($config["allowincomplete"] >= 2 && $match->ended == 2) // Other Endgame
+        $match->ended = 12;
+      else if  ($config["allowincomplete"] >= 3 && $match->ended == 7) // Server Quit
+        $match->ended = 17;
+
+      if ($match->numhumans < 2 && !$config["savesingle"] && ($match->ended == 1 || $match->ended == 12 || $match->ended == 16 || $match->ended == 17))
+        $match->ended = 8;
+      else if ($match->numplayers < 2 && $config["savesingle"] == 1 && ($match->ended == 1 || $match->ended == 12 || $match->ended == 16 || $match->ended == 17))
+        $match->ended = 5;
+    }
 
     switch ($match->ended) {
       case -1:
@@ -641,64 +742,70 @@ while (isset($conflogs["logpath"][$lognum])) {
           else
             echo "not processed.{$break}\n";
         }
-        if (isset($backuppath) && $backuppath)
+        if (isset($backuppath) && $backuppath) {
           copy($file, "{$backuppath}{$logs[$i]}");
+          if ($chatfile != "" && file_exists($chatfile))
+            copy($chatfile, "{$backuppath}{$chatlogs[$i]}");
+        }
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 2:
         echo "unknown endgame reason.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 3:
         echo "invalid.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 4:
         echo "already in database.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 5:
         echo "insufficient players.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 6:
         echo "mapchange.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 7:
         echo "serverquit.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 8:
         echo "insufficient human players.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 9:
         echo "scoreless match.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         break;
       case 10:
         echo "bad parse in database.{$break}\n";
         break;
       case 11:
-        echo "warmup match.{$break}\n";
+        echo "warm-up match.{$break}\n";
         if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
+        break;
+      case 18:
+        echo "no chat log.{$break}\n";
         break;
       default:
         if (!$config["skipinsession"]) {
           echo "incomplete.{$break}\n";
           if (!$save)
-          dellog($file);
+          dellog($file,$chatfile);
         }
         else {
           echo "incomplete (in session?).{$break}\n";
