@@ -489,4 +489,120 @@ INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('nDamTypeShotgunShell','Neot
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('Mine Layer','Neotokyo Smoke/Mines');
 INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('nWeapon_SmokeGrenade','Neotokyo Smoke/Mines');
 #
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_ImpactHammer','Impact Hammer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_ImpactHammer','Impact Hammer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Enforcer','Enforcer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Enforcer','Enforcer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_DualEnforcer','Dual Enforcers');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Grenade','Grenade');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_BioRifle','Bio Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_BioGoo','Bio Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_BioRifle_Content','Bio Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_BioGoo_Charged','Bio Rifle',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_BioGooGib','Bio Rifle',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_LinkGun','Link Gun');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_LinkPlasma','Link Gun');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_LinkBeam','Link Gun',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_ShockRifle','Shock Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_ShockPrimary','Shock Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_InstagibRifle','InstaGib Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_ShockBall','Shock Rifle',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_ShockCombo','Shock Rifle',2);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Stinger','Stinger Minigun');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_StingerBullet','Stinger Minigun');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_StingerShard','Stinger Minigun',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_FlakCannon','Flak Cannon');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_FlakShard','Flak Cannon');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_FlakShell','Flak Cannon',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_RocketLauncher','Rocket Launcher');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Rocket','Rocket Launcher');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_SeekingRocket','Rocket Launcher',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_SniperRifle','Sniper Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_SniperPrimary','Sniper Rifle');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_SniperHeadShot','Sniper Rifle',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Redeemer','Redeemer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Redeemer','Redeemer');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Telefrag','Telefrag');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Translocator','Translocator');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_FailedTranslocation','Translocator');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Avril','AVRiL');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTWeap_Avril_Content','Avril');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_AvrilRocket','Avril');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_SpiderMine','Spider Mine');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_secondary) VALUES('UTDmgType_SpiderMineDirectHit','Spider Mine',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_ShapedCharge','Shaped Charge');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDeployableShapedCharge','Shaped Charge');
+#--------------------------------------------------------------------------------------------------
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('DmgType_Suicided','Suicided');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Instagib','InstaGibbed');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Burning','Burned');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Drowned','Drowned');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Slime','Slimed');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Lava','Fell Into Lava');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('DmgType_Fell','Fell');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Fire','Fire');
+#--------------------------------------------------------------------------------------------------
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionBlade','Scorpion',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionGlob','Scorpion',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionGlobRed','Scorpion',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScorpionSelfDestruct','Scorpion',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_MantaBolt','Manta',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_HellBenderPrimary','Hell Bender',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_GoliathTurret','Goliath',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TankShell','Goliath',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_GoliathMachineGun','Goliath Machine Gun',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_LeviathanBeam','Leviathan',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_LeviathanBolt','Leviathan',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_LeviathanCollision','Leviathan',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_LeviathanExplosion','Leviathan',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_LeviathanRocket','Leviathan',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_LeviathanShard','Leviathan',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_LeviathanShockBall','Leviathan',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_PaladinGun','Paladin',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_PaladinEnergyBolt','Paladin',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_PaladinProximityExplosion','Paladin',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_RaptorGun','Raptor',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_RaptorBolt','Raptor',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_RaptorRocket','Raptor',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_CicadaLaser','Cicada',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_CicadaRocket','Cicada',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_FuryBeam','Fury',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_FuryBolt','Fury',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScavengerBolt','Scavenger',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScavengerStabbed','Scavenger',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ScavengerBallCollision','Scavenger',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_DarkWalkerBolt','Dark Walker',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_DarkWalkerTurretBeam','Dark Walker',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_DarkWalkerTurret','Dark Walker',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_NemesisBeam','Nemisis',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_NemesisTurret','Nemisis',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_NightshadeBeam','Nightshade',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_StealthbenderBeam','Stealthbender',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_SPMAShell','SPMA',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_SPMAShockBall','SPMA',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_SPMAShockBeam','SPMA',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_SPMAShockChain','SPMA',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_SPMASmallShell','SPMA',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_SPMACameraCrush','SPMA',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_ViperBolt','Viper',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_ViperSelfDestruct','Viper',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_Pancake','Pancaked',1,4);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_RanOver','Ran Over',1,4);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_VehicleCollision','Vehicle Collision',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_VehicleExplosion','Vehicle Explosion',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_VehicleShockBall','Vehicle Shock Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_VehicleShockBeam','Vehicle Shock Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype,wp_secondary) VALUES('UTDmgType_VehicleShockChain','Vehicle Shock Turret',1,1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretPrimary','Laser Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTVWeap_RocketTurret','Rocket Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretRocket','Rocket Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretShard','Machine Gun Turret',1);
+INSERT INTO %dbpre%weapons (wp_type,wp_desc,wp_weaptype) VALUES('UTDmgType_TurretShockBall','Shock Turret',1);
+#--------------------------------------------------------------------------------------------------
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_NodeDestruction','Node Destruction');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_EMP','EMP');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_Encroached','Encroached');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_OrbReturn','Orb Return');
+INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('UTDmgType_SpaceDeath','Space Death');
+#
 #INSERT INTO %dbpre%weapons (wp_type,wp_desc) VALUES('','');
